@@ -455,7 +455,7 @@ static apr_status_t impl_pollset_poll(apr_pollset_t *pollset,
     return rv;
 }
 
-static apr_pollset_provider_t impl = {
+static const apr_pollset_provider_t impl = {
     impl_pollset_create,
     impl_pollset_add,
     impl_pollset_remove,
@@ -464,7 +464,7 @@ static apr_pollset_provider_t impl = {
     "port"
 };
 
-apr_pollset_provider_t *apr_pollset_provider_port = &impl;
+const apr_pollset_provider_t *apr_pollset_provider_port = &impl;
 
 static apr_status_t impl_pollcb_cleanup(apr_pollcb_t *pollcb)
 {
@@ -588,7 +588,7 @@ static apr_status_t impl_pollcb_poll(apr_pollcb_t *pollcb,
     return rv;
 }
 
-static apr_pollcb_provider_t impl_cb = {
+static const apr_pollcb_provider_t impl_cb = {
     impl_pollcb_create,
     impl_pollcb_add,
     impl_pollcb_remove,
@@ -597,6 +597,6 @@ static apr_pollcb_provider_t impl_cb = {
     "port"
 };
 
-apr_pollcb_provider_t *apr_pollcb_provider_port = &impl_cb;
+const apr_pollcb_provider_t *apr_pollcb_provider_port = &impl_cb;
 
 #endif /* HAVE_PORT_CREATE */
